<?php
namespace Controllers;

use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DataSource\DataSet;

class Comentarios extends \Teknisa\GER\Controllers\TeknisaCrud {

    protected $dataSourceName = "comentarios";
    protected $dataSourceManager;
    protected $crudService;

    public function __construct($crudService, $parameterBag, $dataSourceManager) {
        $this->dataSourceManager = $dataSourceManager;
        $this->crudService = $crudService;
        $this->parameterBag = $parameterBag;
    }

    public function retornaComentariosFormatados(Request\Filter $request, Response $response) {
        try {
            
            $filterCriteria = $request->getFilterCriteria();
            $filterCriteria->setDataSourceName($this->dataSourceName);
            $filterCriteria = $this->crudService->getFilterCriteriaWithNrOrg($filterCriteria);
            $newFilterCriteria = $this->crudService->getPopulatedFilterCriteria($filterCriteria, array());
            
            $dataSource = $this->dataSourceManager->findBy($newFilterCriteria);
            
            $dataSet = self::formataDataset($dataSource->getRows());
            $response->addDataSet(new DataSet('comentarios', $dataSet));

        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function formataDataset($rows){
        
        $rows_formatado = array();
        
        for($i = 0; $i < count($rows); $i ++){
            
            $tx = $rows[$i]['DSJUSTIFICA'];
            $info = ($rows[$i]['IDAPROVADO'] == 'APROVADO') ? 'Aprovado ' : 'Reprovado ';
            $info = $info.'em '.$rows[$i]['DTAPROVACAO'].' por '.$rows[$i]['NMOPERADOR'];
            
            array_push($rows_formatado, array("TXCOMENTARIO" => $tx,
                                                "INFOCOMENTARIO" => $info,
                                                "CDOPERAPROV" => $rows[$i]['CDOPERAPROV'], 
                                                "NMOPERADOR" => $rows[$i]['NMOPERADOR'], 
                                                "IDAPROVADO" => $rows[$i]['IDAPROVADO'], 
                                                "DTAPROVACAO" => $rows[$i]['DTAPROVACAO'], 
                                                "DSJUSTIFICA" => $rows[$i]['DSJUSTIFICA'])
                                                );
        }
        return $rows_formatado;
    }

}